@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,20 +22,10 @@
 using namespace FollowUpReminder;
 
 FollowUpReminderInfo::FollowUpReminderInfo()
-    : mOriginalMessageItemId(-1)
-    , mAnswerMessageItemId(-1)
-    , mTodoId(-1)
-    , mUniqueIdentifier(-1)
-    , mAnswerWasReceived(false)
 {
 }
 
 FollowUpReminderInfo::FollowUpReminderInfo(const KConfigGroup &config)
-    : mOriginalMessageItemId(-1)
-    , mAnswerMessageItemId(-1)
-    , mTodoId(-1)
-    , mUniqueIdentifier(-1)
-    , mAnswerWasReceived(false)
 {
     readConfig(config);
 }
